package com.ruoyi.business.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import org.apache.ibatis.annotations.*;
import com.ruoyi.business.domain.Adapter;

/**
 * 适配器Mapper接口
 * 
 * @author gx
 * @date 2024-02-22
 */
public interface AdapterMapper extends BaseMapper<Adapter> {

    /**
     * 查询适配器
     * 
     * @param id 适配器主键
     * @return 适配器
     */
    Adapter selectAdapterById(Long id);

    /**
     * 查询适配器列表
     * 
     * @param adapter 适配器
     * @return 适配器集合
     */
    List<Adapter> selectAdapterList(Adapter adapter);

    /**
     * 新增适配器
     * 
     * @param adapter 适配器
     * @return 结果
     */
    int insertAdapter(Adapter adapter);

    /**
     * 修改适配器
     * 
     * @param adapter 适配器
     * @return 结果
     */
    int updateAdapter(Adapter adapter);

    /**
     * 删除适配器
     * 
     * @param id 适配器主键
     * @return 结果
     */
    int deleteAdapterById(Long id);

    /**
     * 批量删除适配器
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAdapterByIds(Long[] ids);

    /**
     * 批量删除适配器（逻辑）
     * @param updateWrapper
     */
     @Update("update b_adapter set ${ew.sqlSet} ${ew.customSqlSegment}")
     int updateByIds(@Param(Constants.WRAPPER) LambdaUpdateWrapper<Adapter> updateWrapper);
}
